-------------------------------------------------------------------------------
--                                                                           --
--  Ada Interface to the X Window System and Motif(tm)/Lesstif               --
--  Copyright (c) 1996-2002 Hans-Frieder Vogt                                --
--  This file also copyright (c) 2002 Vadim Godunko                          --
--                                                                           --
--  Adabindx is free software; you can redistribute it and/or modify it      --
--  under the terms of the GNU General Public License as published by the    --
--  Free Software Foundation; either version 2 of the License, or (at your   --
--  option) any later version.                                               --
--                                                                           --
--  This program is distributed in the hope that it will be useful, but      --
--  WITHOUT ANY WARRANTY; without even the implied warranty of               --
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                     --
--  See the GNU General Public License for more details.                     --
--                                                                           --
--  You should have received a copy of the GNU General Public License        --
--  along with this program; if not, write to the                            --
--  Free Software Foundation, Inc.,                                          --
--  59 Temple Place - Suite 330,                                             --
--  Boston, MA 02111-1307, USA.                                              --
--                                                                           --
--  As a special exception, if other files instantiate generics from this    --
--  unit, or you link this unit with other files to produce an executable,   --
--  this unit does not by itself cause the resulting executable to be        --
--  covered by the GNU General Public License. This exception does not       --
--  however invalidate any other reasons why the executable file might be    --
--  covered by the GNU General Public License.                               --
--                                                                           --
--  X Window System is copyrighted by the X Consortium                       --
--  Motif(tm)       is copyrighted by the Open Software Foundation, Inc.     --
--                  and by The Open Group                                    --
--                                                                           --
--                                                                           --
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--
-- HISTORY:
--          2002-10-20 Vadim Godunko: first definition of this file
--
-------------------------------------------------------------------------------

package Xm_Widgets.Manager.Bulletin_Board.Column is

--  UseOpenMotif2.2

   Xm_Column_Widget_Class : constant Widget_Class;


   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> Xm_Is_Column
   --!    <Purpose>
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function Xm_Is_Column (W : in Widget) return Boolean;


   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> Xm_Create_Column
   --!    <Purpose>
   --!    <Exceptions>
   ---------------------------------------------------------------------------
   function Xm_Create_Column (Parent  : in Widget;
                              Name    : in String;
                              Arglist : in Arg_List := Null_Arg_List)
     return Widget;

--   currently not implemented
--   function Xm_Column_Get_Child_Label () return Widget;


   Xm_N_Default_Entry_Label_Alignment : constant Xt_N_Resource_String;
   Xm_N_Default_Entry_Label_Font_List : constant Xt_N_Resource_String;
   Xm_N_Default_Fill_Style            : constant Xt_N_Resource_String;
   Xm_N_Distribution                  : constant Xt_N_Resource_String;

   type Distribution is (Spread, Tight);

   procedure Append_Set (List  : in out Arg_List;
                         Name  : in     Xt_N_Resource_String;
                         Value : in     Distribution);

   procedure Append_Get (List  : in out Arg_List;
                         Name  : in     Xt_N_Resource_String;
                         Value :    out Distribution);
   pragma Convention (C, Append_Get);

   Xm_N_Item_Spacing                  : constant Xt_N_Resource_String;
   Xm_N_Label_Spacing                 : constant Xt_N_Resource_String;
   Xm_N_Orientation                   : constant Xt_N_Resource_String;

   --  constraint resources

   Xm_N_Entry_Label_Alignment         : constant Xt_N_Resource_String;
   Xm_N_Entry_Label_Font_List         : constant Xt_N_Resource_String;
   Xm_N_Entry_Label_Pixmap            : constant Xt_N_Resource_String;
   Xm_N_Entry_Label_String            : constant Xt_N_Resource_String;
   Xm_N_Entry_Label_Type              : constant Xt_N_Resource_String;
   Xm_N_Fill_Style                    : constant Xt_N_Resource_String;

   type Fill_Style is (Unspecified, Flush, Ragged);

   procedure Append_Set (List  : in out Arg_List;
                         Name  : in     Xt_N_Resource_String;
                         Value : in     Fill_Style);

   procedure Append_Get (List  : in out Arg_List;
                         Name  : in     Xt_N_Resource_String;
                         Value :    out Fill_Style);
   pragma Convention (C, Append_Get);

   Xm_N_Show_Entry_Label              : constant Xt_N_Resource_String;
   Xm_N_Stretchable                   : constant Xt_N_Resource_String;


private

   for Distribution use (Spread => 0, Tight => 1);
   for Distribution'Size use Interfaces.C.unsigned_char'Size;

   for Fill_Style use (Unspecified => 0, Flush => 1, Ragged => 2);
   for Fill_Style'Size use Interfaces.C.unsigned_char'Size;

   c_const_Xm_Column_Widget_Class : Widget_Class;
   pragma Import (C, c_const_Xm_Column_Widget_Class, "xmColumnWidgetClass");

   Xm_Column_Widget_Class : constant Widget_Class :=
     c_const_Xm_Column_Widget_Class;


   Xm_N_Default_Entry_Label_Alignment : constant Xt_N_Resource_String :=
     To_Resource_String("defaultEntryLabelAlignment");
   Xm_N_Default_Entry_Label_Font_List : constant Xt_N_Resource_String :=
     To_Resource_String("defaultEntryLabelFontList");
   Xm_N_Default_Fill_Style            : constant Xt_N_Resource_String :=
     To_Resource_String("defaultFillStyle");
   Xm_N_Distribution                  : constant Xt_N_Resource_String :=
     To_Resource_String("distribution");
   Xm_N_Item_Spacing                  : constant Xt_N_Resource_String :=
     To_Resource_String("itemSpacing");
   Xm_N_Label_Spacing                 : constant Xt_N_Resource_String :=
     To_Resource_String("labelSpacing");
   Xm_N_Orientation                   : constant Xt_N_Resource_String :=
     X_Toolkit.Xt_N_Orientation;

   --  constraint resources

   Xm_N_Entry_Label_Alignment         : constant Xt_N_Resource_String :=
     To_Resource_String("entryLabelAlignment");
   Xm_N_Entry_Label_Font_List         : constant Xt_N_Resource_String :=
     To_Resource_String("entryLabelFontList");
   Xm_N_Entry_Label_Pixmap            : constant Xt_N_Resource_String :=
     To_Resource_String("entryLabelPixmap");
   Xm_N_Entry_Label_String            : constant Xt_N_Resource_String :=
     To_Resource_String("entryLabelString");
   Xm_N_Entry_Label_Type              : constant Xt_N_Resource_String :=
     To_Resource_String("entryLabelType");
   Xm_N_Fill_Style                    : constant Xt_N_Resource_String :=
     To_Resource_String("fillStyle");
   Xm_N_Show_Entry_Label              : constant Xt_N_Resource_String :=
     To_Resource_String("showEntryLabel");
   Xm_N_Stretchable                   : constant Xt_N_Resource_String :=
     To_Resource_String("stretchable");

--  EndOpenMotif2.2

end Xm_Widgets.Manager.Bulletin_Board.Column;
