-------------------------------------------------------------------------------
--                                                                           --
--  Ada Interface to the X Window System and Motif(tm)/Lesstif               --
--  Copyright (c) 1996-2002 Hans-Frieder Vogt                                --
--  This file also copyright (c) 2002 Vadim Godunko                          --
--                                                                           --
--  Adabindx is free software; you can redistribute it and/or modify it      --
--  under the terms of the GNU General Public License as published by the    --
--  Free Software Foundation; either version 2 of the License, or (at your   --
--  option) any later version.                                               --
--                                                                           --
--  This program is distributed in the hope that it will be useful, but      --
--  WITHOUT ANY WARRANTY; without even the implied warranty of               --
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                     --
--  See the GNU General Public License for more details.                     --
--                                                                           --
--  You should have received a copy of the GNU General Public License        --
--  along with this program; if not, write to the                            --
--  Free Software Foundation, Inc.,                                          --
--  59 Temple Place - Suite 330,                                             --
--  Boston, MA 02111-1307, USA.                                              --
--                                                                           --
--  As a special exception, if other files instantiate generics from this    --
--  unit, or you link this unit with other files to produce an executable,   --
--  this unit does not by itself cause the resulting executable to be        --
--  covered by the GNU General Public License. This exception does not       --
--  however invalidate any other reasons why the executable file might be    --
--  covered by the GNU General Public License.                               --
--                                                                           --
--  X Window System is copyrighted by the X Consortium                       --
--  Motif(tm)       is copyrighted by the Open Software Foundation, Inc.     --
--                  and by The Open Group                                    --
--                                                                           --
--                                                                           --
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
--
-- HISTORY:
--          2002-10-13  Vadim Godunko: first definition of this file
--
-------------------------------------------------------------------------------

package Xm_Widgets.Primitive.Text.Data_Field is

--UseOpenMotif2.2

   Xm_Data_Field_Widget_Class : constant Widget_Class;

   type Xm_Data_Field_Callback_Struct is record
      W    : Widget;
      Text : X_Strings.X_String;
      Doit : Boolean;
   end record;
   pragma Convention (C, Xm_Data_Field_Callback_Struct);

   type Xm_Data_Field_Callback_Struct_Access is
     access all Xm_Data_Field_Callback_Struct;


   Xm_Data_Field_Dont_Own_Primary_Selection : exception;
   Xm_Data_Field_Not_In_Data_Field_Widget   : exception;


   function Xm_Is_Data_Field (W : in Widget) return Boolean;

   function Xm_Create_Data_Field (Parent  : in Widget;
                                  Name    : in String;
                                  Arglist : in Arg_List := Null_Arg_List)
     return Widget;

   procedure Xm_Data_Field_Set_String (W     : in Widget;
                                       Value : in String);

   --  procedure Xm_Data_Field_Set_String (W     : in Widget;
   --                                      Value : in Wide_String);

   function Xm_Data_Field_Get_String (W : in Widget) return String;

   function Xm_Data_Field_Get_String (W : in Widget) return Wide_String;

   --  Xm_Data_Field_Get_Substring
   --  Xm_Data_Field_Get_Substring_Wcs

   function Xm_Data_Field_Get_Last_Position (W : in Widget)
     return Xm_Text_Position;

   procedure Xm_Data_Field_Replace (W             : in Widget;
                                    From_Position : in Xm_Text_Position;
                                    To_Position   : in Xm_Text_Position;
                                    Value         : in String);

   procedure Xm_Data_Field_Replace (W             : in Widget;
                                    From_Position : in Xm_Text_Position;
                                    To_Position   : in Xm_Text_Position;
                                    Value         : in Wide_String);

   procedure Xm_Data_Field_Insert (W        : in Widget;
                                   Position : in Xm_Text_Position;
                                   Value    : in String);

   procedure Xm_Data_Field_Insert (W        : in Widget;
                                   Position : in Xm_Text_Position;
                                   Value    : in Wide_String);

   procedure Xm_Data_Field_Set_Add_Mode (W     : in Widget;
                                         State : in Boolean);

   function Xm_Data_Field_Get_Add_Mode (W : in Widget) return Boolean;

   procedure Xm_Data_Field_Set_Highlight (W      : in Widget;
                                          Left   : in Xm_Text_Position;
                                          Right  : in Xm_Text_Position;
                                          Mode   : in Xm_Highlight_Mode);

   function Xm_Data_Field_Get_Editable (W : in Widget) return Boolean;

   procedure Xm_Data_Field_Set_Editable (W        : in Widget;
                                         Editable : in Boolean);

   function Xm_Data_Field_Get_Max_Length (W : in Widget) return Integer;

   procedure Xm_Data_Field_Set_Max_Length (W          : in Widget;
                                           Max_Length : in Integer);

   function Xm_Data_Field_Get_Cursor_Position (W : in Widget)
     return Xm_Text_Position;

   function Xm_Data_Field_Get_Insertion_Position (W : in Widget)
     return Xm_Text_Position;

   procedure Xm_Data_Field_Set_Insertion_Position
    (W        : in Widget;
     Position : in Xm_Text_Position);

   function Xm_Data_Field_Get_Selection (W : in Widget) return String;

   function Xm_Data_Field_Get_Selection (W : in Widget) return Wide_String;

   procedure Xm_Data_Field_Set_Selection (W     : in Widget;
                                          First : in Xm_Text_Position;
                                          Last  : in Xm_Text_Position;
                                          Time  : in X_Lib.Server_Time);

   procedure Xm_Data_Field_Get_Selection_Position
    (W     : in     Widget;
     Left  :    out Xm_Text_Position;
     Right :    out Xm_Text_Position);

   function Xm_Data_Field_XY_To_Pos (W : in Widget;
                                     X : in X_Lib.Position;
                                     Y : in X_Lib.Position)
     return Xm_Text_Position;


   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> Xm_Data_Field_Pos_To_XY
   --!    <Purpose>
   --!    <Exceptions>
   --!       Xm_Data_Field_Not_In_Data_Field_Widget - character position
   --!     not displayed in widget.
   ---------------------------------------------------------------------------
   procedure Xm_Data_Field_Pos_To_XY (W        : in     Widget;
                                      Position : in     Xm_Text_Position;
                                      X        :    out X_Lib.Position;
                                      Y        :    out X_Lib.Position);


   procedure Xm_Data_Field_Show_Position (W        : in Widget;
                                          Position : in Xm_Text_Position);


   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> Xm_Data_Field_Cut
   --!    <Purpose>
   --!    <Exceptions>
   --!       Xm_Data_Field_Donr_Own_Primary_Selection
   ---------------------------------------------------------------------------
   procedure Xm_Data_Field_Cut (W         : in Widget;
                                Clip_Time : in X_Lib.Server_Time);


   ---------------------------------------------------------------------------
   --! <Subprogram>
   --!    <Unit> Xm_Data_Field_Copy
   --!    <Purpose>
   --!    <Exceptions>
   --!       Xm_Data_Field_Donr_Own_Primary_Selection
   ---------------------------------------------------------------------------
   procedure Xm_Data_Field_Copy (W         : in Widget;
                                 Clip_Time : in X_Lib.Server_Time);


   procedure Xm_Data_Field_Paste (W : in Widget);

   function Xm_Data_Field_Get_Baseline (W : in Widget) return Integer;


   Xm_N_Alignment              : constant Xt_N_Resource_String;
   Xm_N_Auto_Fill              : constant Xt_N_Resource_String;
   Xm_N_Picture                : constant Xt_N_Resource_String;
   Xm_N_Picture_Error_Callback : constant Xt_N_Resource_String;
   Xm_N_Validate_Callback      : constant Xt_N_Resource_String;


private

   c_const_Xm_Data_Field_Widget_Class : Widget_Class;
   pragma Import (C, c_const_Xm_Data_Field_Widget_Class,
                  "xmDataFieldWidgetClass");

   Xm_Data_Field_Widget_Class : constant Widget_Class :=
     c_const_Xm_Data_Field_Widget_Class;


   Xm_N_Alignment              : constant Xt_N_Resource_String :=
     Xm_Widgets.Primitive.Xm_N_Alignment;
   Xm_N_Auto_Fill              : constant Xt_N_Resource_String :=
     To_Resource_String ("autoFill");
   Xm_N_Picture                : constant Xt_N_Resource_String :=
     To_Resource_String ("picture");
   Xm_N_Picture_Error_Callback : constant Xt_N_Resource_String :=
     To_Resource_String ("pictureErrorCallback");
   Xm_N_Validate_Callback      : constant Xt_N_Resource_String :=
     To_Resource_String ("validateCallback");


   pragma Import (C, Xm_Data_Field_Get_Baseline,"XmDataFieldGetBaseline");
   pragma Import (C, Xm_Data_Field_Get_Cursor_Position,
                  "XmDataFieldGetCursorPosition");
   pragma Import (C, Xm_Data_Field_Get_Insertion_Position,
                  "XmDataFieldGetInsertionPosition");
   pragma Import (C, Xm_Data_Field_Get_Last_Position,
                  "XmDataFieldGetLastPosition");
   pragma Import (C, Xm_Data_Field_Get_Max_Length, "XmDataFieldGetMaxLength");
   pragma Import (C, Xm_Data_Field_Get_Selection_Position,
                  "XmDataFieldGetSelectionPosition");
   pragma Import (C, Xm_Data_Field_Set_Highlight, "XmDataFieldSetHighlight");
   pragma Import (C, Xm_Data_Field_Set_Insertion_Position,
                  "XmDataFieldSetInsertionPosition");
   pragma Import (C, Xm_Data_Field_Set_Max_Length, "XmDataFieldSetMaxLength");
   pragma Import (C, Xm_Data_Field_Set_Selection, "XmDataFieldSetSelection");
   pragma Import (C, Xm_Data_Field_Show_Position, "XmDataFieldShowPosition");
   pragma Import (C, Xm_Data_Field_XY_To_Pos, "XmDataFieldXYToPos");

--EndOpenMotif2.2

end Xm_Widgets.Primitive.Text.Data_Field;
